{% load i18n %}

<h1>{% trans "Technology Radar" %}</h1>
{% if radars %}
<ul>
    {% for radar in radars %}
    <li>
        <a href="{% url 'radar-detail' radar.slug %}">{{ radar.name }}</a>
    </li>
    {% endfor %}
</ul>
{% else %}
<p>{% trans "No radars are available." %}</p>
{% endif %}
