{% load i18n technology_radar_tags %}

<h1>{{ radar.name }}</h1>
{% for area in areas %}
    <h2>{{ area.name }}</h2>
    {% get_radar_blips_by_area radar area as area_blips %}
    {% if area_blips %}
    <ul>
        {% for blip in area_blips %}
        <li>
            <a href="{% url 'blip-detail' radar.slug blip.area.slug blip.slug %}">{{ blip.name }} ({{ blip.status }}){% if blip.is_new %} <span class="badge">{% trans "new" %}</span>{% endif %}</a>
        </li>
        {% endfor %}
    </ul>
    {% else %}
    <p>{% trans "No blips are available." %}</p>
    {% endif %}
{% endfor %}
<p>
    <a href="{% url 'radar-detail-download' radar.slug %}">{% trans "Download" %}</a>
</p>
